-----------------------------------------------------------------------------------------------
-- Client Lua Script for HideCTFContainer
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Apollo"
require "GameLib"
require "Window"
require "Unit"

-------------------------------------------------------------------------------------
-- HideCTFContainer Module Definition
-----------------------------------------------------------------------------------------------
local HideCTFContainer = {}
local ok = 0 
local runOnce = true
local matchTrackerAddon_OnDocumentReady = nil
local matchTrackerAddon = Apollo.GetAddon("MatchTracker")
local ktRavelIdToCTFWindowName =
{
	[0] = "CTFNeutralFlag",
	[1] = "CTFExilesHaveFlag",
	[2] = "CTFDomHaveFlag",
	[9] = "CTFStolenFlag",
}


-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function HideCTFContainer:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    return o
end

function HideCTFContainer:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {"MatchTracker"}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
 
-----------------------------------------------------------------------------------------------
-- HideCTFContainer OnLoad
-----------------------------------------------------------------------------------------------
function HideCTFContainer:OnLoad()
	MatchTrackerBase_OnDocumentReady = matchTrackerAddon.OnDocumentReady
	matchTrackerAddon.OnDocumentReady = HideCTFContainer.MatchTrackerHook_OnDocumentReady
	Apollo.RegisterTimerHandler("OneSecTimer", "OnTimer", self)	
end

function HideCTFContainer.MatchTrackerHook_OnDocumentReady(matchTrackerSelf)
	MatchTrackerBase_OnDocumentReady(matchTrackerSelf)  -- this will create the MatchTracker
	local matchTracker = matchTrackerSelf		
end

function HideCTFContainer:OnTimer()
	if runOnce == true then
		if matchTrackerAddon ~= nil then
			matchTrackerAddon.HelperCTFPlusOneFlag = self.HelperCTFPlusOneFlag
			matchTrackerAddon.HelperCTFMinusOneFlag = self.HelperCTFMinusOneFlag
			--Print("HideCTFContainer loaded")
		end
	end	
end

function HideCTFContainer:HelperCTFPlusOneFlag(nArg)
	local strWindowName = ktRavelIdToCTFWindowName[nArg]
	self.tWndRefs.wndMatchTracker:FindChild("CTFAlertContainer"):Show(false) -- new
	if strWindowName then
		--self.tWndRefs.wndMatchTracker:FindChild(strWindowName):Show(true)
		--self.tWndRefs.wndMatchTracker:FindChild(strWindowName):SetData(self.tWndRefs.wndMatchTracker:FindChild(strWindowName):GetData() + 1)
		--self.tWndRefs.wndMatchTracker:FindChild("CTFAlertContainer"):ArrangeChildrenVert(1)
	end
end

function HideCTFContainer:HelperCTFMinusOneFlag(nArg)
	local strWindowName = ktRavelIdToCTFWindowName[nArg]
	self.tWndRefs.wndMatchTracker:FindChild("CTFAlertContainer"):Show(false) -- new
	if strWindowName then
		self.tWndRefs.wndMatchTracker:FindChild(strWindowName):SetData(math.max(0, self.tWndRefs.wndMatchTracker:FindChild(strWindowName):GetData() - 1))
	end
	self.tWndRefs.wndMatchTracker:FindChild("CTFNeutralFlag"):Show(self.tWndRefs.wndMatchTracker:FindChild("CTFNeutralFlag"):GetData() > 0)
	self.tWndRefs.wndMatchTracker:FindChild("CTFDomHaveFlag"):Show(self.tWndRefs.wndMatchTracker:FindChild("CTFDomHaveFlag"):GetData() > 0)
	self.tWndRefs.wndMatchTracker:FindChild("CTFStolenFlag"):Show(self.tWndRefs.wndMatchTracker:FindChild("CTFStolenFlag"):GetData() > 0)
	self.tWndRefs.wndMatchTracker:FindChild("CTFExilesHaveFlag"):Show(self.tWndRefs.wndMatchTracker:FindChild("CTFExilesHaveFlag"):GetData() > 0)
	--self.tWndRefs.wndMatchTracker:FindChild("CTFAlertContainer"):ArrangeChildrenVert(1)
end


-----------------------------------------------------------------------------------------------
-- HideCTFContainer Instance
-----------------------------------------------------------------------------------------------
local HideCTFContainerInst = HideCTFContainer:new()
HideCTFContainerInst:Init()
